<template>
  <div class="flex w-full h-full overflow-hidden">
    <content-wrapper title="区" class="w-250 mr-20 overflow-auto">
      <template #header-right>
        <el-button
          circle
          icon="el-icon-plus"
          type="primary"
          @click="newArea"
        ></el-button>
      </template>
      <el-bus-crud ref="areaCrudRef" v-bind="areaTableConfig">
        <template #table="{ list }">
          <template v-if="list && list.length > 0">
            <div
              v-for="item in list"
              :key="item.id"
              class="area-item"
              :class="{ 'is-active': selectedArea === item.id }"
              @click="onSelectArea(item.id)"
            >
              <span class="area-item__label">{{ item.name }}</span>
              <el-dropdown>
                <i class="el-icon-more-outline"></i>
                <el-dropdown-menu slot="dropdown">
                  <el-dropdown-item @click.native="editArea(item)"
                    >编辑</el-dropdown-item
                  >
                  <el-dropdown-item @click.native="deleteArea(item)"
                    >删除</el-dropdown-item
                  >
                </el-dropdown-menu>
              </el-dropdown>
            </div>
          </template>
          <el-bus-empty v-else />
        </template>
      </el-bus-crud>
    </content-wrapper>
    <content-wrapper title="仓位" class="flex-1 overflow-auto">
      <template #header-right>
        <el-button
          circle
          icon="el-icon-plus"
          type="primary"
          @click="newLocation"
        ></el-button>
      </template>
      <el-bus-crud
        ref="locationCrudRef"
        v-bind="locationTableConfig"
        :key="selectedArea"
        :extra-query="locationExtra"
      >
        <template #table="{ list }">
          <el-row v-if="list && list.length > 0" :gutter="20">
            <el-col v-for="item in list" :key="item.id" :span="8">
              <location-item
                :info="item"
                @edit="onEditLocation(item)"
                @delete="onDeleteLocation(item)"
                @addOrder="addOrder(item)"
              ></location-item>
            </el-col>
          </el-row>
          <el-bus-empty v-else />
        </template>
      </el-bus-crud>
    </content-wrapper>
  </div>
</template>

<script>
import { getSortConfig } from '@/utils/form-item-config'
import LocationItem from '@/components/warehouse/location-item.vue'
import SelectOrder from '@/components/warehouse/select-order.vue'
export default {
  components: {
    LocationItem,
  },
  data() {
    return {
      selectedArea: null,
      areaTableConfig: {
        url: 'flower/api/warehouse/list',
        hasNew: false,
        newText: '新增区',
        hasPagination: false,
        form: [
          {
            label: '区号：',
            id: 'name',
            type: 'input',
            rules: { required: true, message: '请输入区号', trigger: 'blur' },
          },
          {
            ...getSortConfig('seq'),
          },
        ],
      },
      locationTableConfig: {
        url: 'flower/api/warehouse/location/list',
        hasNew: false,
        newText: '新增仓位',
        hasPagination: false,
        extraParentKeys: ['warehouseId'],
        afterRequest: (list) => {
          return list.map((item) => {
            const orderList = item.orderDTO || []
            const goodsItems = orderList.reduce((total, current) => {
              total = total.concat(
                current.items.map((i) => ({
                  ...i,
                  orderNo: current.orderNo,
                }))
              )
              return total
            }, [])
            return { ...item, goodsItems }
          })
        },
        searchForm: [
          {
            type: 'row',
            items: [{ label: '仓位号', id: 'code', type: 'input' }],
          },
        ],
        form: [
          {
            label: '区号：',
            id: 'warehouseId',
            type: 'bus-select',
            el: {
              interfaceUri: 'flower/api/warehouse/list',
              props: {
                label: 'name',
                value: 'id',
              },
              style: 'width:100%',
            },
            rules: { required: true, message: '请选择区号' },
          },
          {
            label: '仓位号：',
            id: 'code',
            type: 'input',
            rules: { required: true, message: '请输入仓位号', trigger: 'blur' },
          },
          {
            ...getSortConfig('seq'),
          },
        ],
        extraDialogs: [
          {
            title: '添加订单',
            hiddenReverseItems: [],
            dialogAttrs: {
              width: '80%',
              destroyOnClose: true,
            },
            form: [
              {
                label: '',
                id: 'orderId',
                component: SelectOrder,
                rules: { required: true, message: '请选择一个订单' },
              },
            ],
            atConfirm: async (val) => {
              const { code } = await this.$elBusHttp.request(
                'flower/api/warehouse/location/list/addOrder',
                {
                  params: {
                    ...val,
                    warehouseLocationId: val.id,
                  },
                }
              )
              if (code === 0) {
                this.$message.success('添加订单成功')
              }
            },
          },
        ],
      },
    }
  },
  head() {
    return {
      title: '仓库管理',
    }
  },
  computed: {
    locationExtra() {
      return {
        warehouseId: this.selectedArea,
      }
    },
  },
  methods: {
    onSelectArea(id) {
      if (this.selectedArea === id) {
        this.selectedArea = null
      } else {
        this.selectedArea = id
      }
    },
    newArea() {
      if (this.$refs.areaCrudRef) {
        this.$refs.areaCrudRef.onDefaultNew()
      }
    },
    editArea(item) {
      if (this.$refs.areaCrudRef) {
        this.$refs.areaCrudRef.onDefaultEdit(item)
      }
    },
    deleteArea(item) {
      if (this.$refs.areaCrudRef) {
        this.$refs.areaCrudRef.onDefaultDelete(item)
      }
    },
    newLocation() {
      if (this.$refs.locationCrudRef) {
        if (this.selectedArea) {
          this.$refs.locationCrudRef.onDefaultNew(
            { warehouseId: this.selectedArea },
            true
          )
        } else {
          this.$refs.locationCrudRef.onDefaultNew()
        }
      }
    },
    onEditLocation(item) {
      if (this.$refs.locationCrudRef) {
        this.$refs.locationCrudRef.onDefaultEdit(item)
      }
    },
    onDeleteLocation(item) {
      if (this.$refs.locationCrudRef) {
        this.$refs.locationCrudRef.onDefaultDelete(item)
      }
    },
    addOrder(item) {
      this.$refs.locationCrudRef.$refs.extraDialog[0].show(item)
    },
  },
}
</script>

<style lang="scss" scoped>
::v-deep {
  .el-bus-crud {
    &__card,
    &__body {
      padding: 0;
    }
    &__filter {
      padding-top: 0;
      border-bottom: none;
    }
  }
}
.area-item {
  height: 40px;
  line-height: 40px;
  cursor: pointer;
  padding: 0 10px;
  color: $main-title-color;
  font-size: 14px;
  display: flex;
  align-items: center;
  &__label {
    flex: 1;
  }
  .el-icon-more-outline {
    color: $primary-color;
    display: none;
  }
  &:hover {
    background-color: #f5f7fa;
    .el-icon-more-outline {
      display: block;
    }
  }
  &.is-active {
    background-color: #edf0ff;
  }
}
</style>
